==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebValidationErrorsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescription } from "./WebValidationErrorsDescription";
/**
 * @hidden
 */
export let WebValidationErrorsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValidationErrorsDescriptionMetadata extends Base {
        static b(a) {
            if (WebValidationErrorsDescriptionMetadata.a == null) {
                WebValidationErrorsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValidationErrorsDescriptionMetadata.c(WebValidationErrorsDescriptionMetadata.a);
            }
            if (a.k(WebValidationErrorsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebValidationErrorsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValidationErrors");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebValidationErrorsDescriptionMetadata.b(a);
            a.ad("WebValidationErrors", () => new WebValidationErrorsDescription());
            a.ac("WebValidationErrors", WebValidationErrorsDescriptionMetadata.a);
        }
    }
    WebValidationErrorsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValidationErrorsDescriptionMetadata, 'WebValidationErrorsDescriptionMetadata');
    WebValidationErrorsDescriptionMetadata.a = null;
    return WebValidationErrorsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebValidationErrorsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescription } from "./WebValidationErrorsDescription";
/**
 * @hidden
 */
export let WebValidationErrorsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValidationErrorsDescriptionMetadata extends Base {
        static b(a) {
            if (WebValidationErrorsDescriptionMetadata.a == null) {
                WebValidationErrorsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValidationErrorsDescriptionMetadata.c(WebValidationErrorsDescriptionMetadata.a);
            }
            if (a.k(WebValidationErrorsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebValidationErrorsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValidationErrors");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebValidationErrorsDescriptionMetadata.b(a);
            a.ae("WebValidationErrors", () => new WebValidationErrorsDescription());
            a.ad("WebValidationErrors", WebValidationErrorsDescriptionMetadata.a);
        }
    }
    WebValidationErrorsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValidationErrorsDescriptionMetadata, 'WebValidationErrorsDescriptionMetadata');
    WebValidationErrorsDescriptionMetadata.a = null;
    return WebValidationErrorsDescriptionMetadata;
})();
